summaryrefslogtreecommitdiffstats
path: root/src/map/mio/mioFunc.c
diff options
context:
space:
mode:
authorAlan Mishchenko <alanmi@berkeley.edu>2009-02-15 08:01:00 -0800
committerAlan Mishchenko <alanmi@berkeley.edu>2009-02-15 08:01:00 -0800
commit0871bffae307e0553e0c5186336189e8b55cf6a6 (patch)
tree4571d1563fe33a53a57fea1c35fb668b9d33265f /src/map/mio/mioFunc.c
parentf936cc0680c98ffe51b3a1716c996072d5dbf76c (diff)
downloadabc-0871bffae307e0553e0c5186336189e8b55cf6a6.tar.gz
abc-0871bffae307e0553e0c5186336189e8b55cf6a6.tar.bz2
abc-0871bffae307e0553e0c5186336189e8b55cf6a6.zip
Version abc90215
Diffstat (limited to 'src/map/mio/mioFunc.c')
-rw-r--r--src/map/mio/mioFunc.c8
1 files changed, 5 insertions, 3 deletions
diff --git a/src/map/mio/mioFunc.c b/src/map/mio/mioFunc.c
index 1fca5764..a06151f0 100644
--- a/src/map/mio/mioFunc.c
+++ b/src/map/mio/mioFunc.c
@@ -144,7 +144,7 @@ int Mio_GateParseFormula( Mio_Gate_t * pGate )
{
// get the topmost (generic) pin
pPin = pGate->pPins;
- FREE( pPin->pName );
+ ABC_FREE( pPin->pName );
// create individual pins from the generic pin
ppPin = &pPin->pNext;
@@ -173,10 +173,10 @@ int Mio_GateParseFormula( Mio_Gate_t * pGate )
{
if ( pPinNames[i] && strcmp( pPinNames[i], pPin->pName ) == 0 )
{
// free pPinNames[i] because it is already available as pPin->pName
// setting pPinNames[i] to NULL is useful to make sure that
// this name is not assigned to two pins in the list
- FREE( pPinNames[i] );
+ ABC_FREE( pPinNames[i] );
pPinNamesCopy[iPin++] = pPin->pName;
break;
}
@@ -212,6 +212,8 @@ int Mio_GateParseFormula( Mio_Gate_t * pGate )
// derive the formula as the BDD
pGate->bFunc = Parse_FormulaParser( stdout, pGate->pForm, nPins, 0, pPinNames, dd, dd->vars );
+ if ( pGate->bFunc == NULL )
+ return 1;
Cudd_Ref( pGate->bFunc );
// derive the cover (SOP)
@@ -173,10 +173,10 @@ int Mio_GateParseFormula( Mio_Gate_t * pGate )
if ( pPinNames[i] && strcmp( pPinNames[i], pPin->pName ) == 0 )
{
- // free pPinNames[i] because it is already available as pPin->pName
+ // ABC_FREE pPinNames[i] because it is already available as pPin->pName
// setting pPinNames[i] to NULL is useful to make sure that
// this name is not assigned to two pins in the list